@@ -148,3 +148,21 @@ class CBParameterError(CBError):
     """
     Exception raised if one or more request parameters are invalid
     """
+
+
+class CBSSHConnectionError(CBError):
+    """
+    Exception raised if paramiko connect failed
+    """
+
+
+class CBSSHKafkaWriteError(CBError):
+    """
+    Exception raised if ssh_kafka_write has data on stderr
+    """
+
+
+class CBSSHKafkaReadError(CBError):
+    """
+    Exception raised if ssh_kafka_read has data on stderr
+    """
